@@ -1,12 +1,12 @@
 package WWW::GitHub::Gist;
 {
-  $WWW::GitHub::Gist::VERSION = '0.14';
+  $WWW::GitHub::Gist::VERSION = '0.15';
 }
 
 use strict;
 use warnings;
 
-use base qw(WWW::GitHub::Gist::v2);
+use base qw(WWW::GitHub::Gist::v3);
 
 =head1 NAME
 
@@ -14,31 +14,26 @@ WWW::GitHub::Gist - Perl interface to the GitHub's pastebin service
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
     use WWW::GitHub::Gist;
 
-    # WWW::GitHub::Gist::v2 by default
+    # WWW::GitHub::Gist::v3 by default
     my $gist = WWW::GitHub::Gist -> new(...);
 
-See L<WWW::GitHub::Gist::v2> for more information.
+See L<WWW::GitHub::Gist::v3> for more information.
 
 =head1 DESCRIPTION
 
 L<WWW::GitHub::Gist> provides an object-oriented interface for Perl to the
 L<gist.github.com> API. Gist is a pastebin service operated by GitHub.
 
-You can use either the L<v2|WWW::GitHub::Gist::v2> of the API (default),
-or the L<v3|WWW::GitHub::Gist::v3>.
-
 =head1 SEE ALSO
 
 =over 4
 
-=item L<WWW::GitHub::Gist::v2>
-
 =item L<WWW::GitHub::Gist::v3>
 
 =back
